
|Travis|_ |Coveralls|_ |Python27|_ |Python34|_ |PyPi|_ 

.. |Travis| image:: https://travis-ci.org/neurospin/pydcmio.svg?branch=master
.. _Travis: https://travis-ci.org/neurospin/pydcmio

.. |Coveralls| image:: https://coveralls.io/repos/neurospin/pydcmio/badge.svg?branch=master&service=github
.. _Coveralls: https://coveralls.io/github/neurospin/pydcmio

.. |Python27| image:: https://img.shields.io/badge/python-2.7-blue.svg
.. _Python27: https://badge.fury.io/py/pydcmio

.. |Python34| image:: https://img.shields.io/badge/python-3.4-blue.svg
.. _Python34: https://badge.fury.io/py/pydcmio

.. |PyPi| image:: https://badge.fury.io/py/pydcmio.svg
.. _PyPi: https://badge.fury.io/py/pydcmio

========================
PYDCMIO: Python DiCoM IO 
========================
  

[pydcmio] A Python project that provides a wrapping over the 'dcm2nii' command,
common tools to read and anonymize DICOM files, and transcoding features.
Visit also the `API documentation <http://neurospin.github.io/pydcmio>`_.





